@@ -71,7 +71,6 @@ Graphics::Graphics( DG *dg, int argc, char **argv ) throw (class GraphicsExcepti
 
         _use3dfx = false;
         
-        _grab = true;
         _fullscreen = false;
         
         _dg = dg;
@@ -86,7 +85,7 @@ Graphics::Graphics( DG *dg, int argc, char **argv ) throw (class GraphicsExcepti
 	for ( int i=1; argv[i]; ++i ) {
 
                 if ( strcmp( argv[i], "-nograb" ) == 0 ) {
-                        _grab = false;
+                        g_state.grab_input = false;
                         continue;
                 }
 
@@ -201,7 +200,7 @@ Graphics::Graphics( DG *dg, int argc, char **argv ) throw (class GraphicsExcepti
 
         cout << " opening audio " << endl;
         
-        if ( Mix_OpenAudio( 44100, AUDIO_S16, 2, 4096 ) < 0 ) {
+        if ( Mix_OpenAudio( 11025, AUDIO_S16, 2, 512 ) < 0 ) {
                 cout << "can't open audio: " << SDL_GetError() << endl;
                 SDL_Quit();
                 exit( 1 );
@@ -254,7 +253,7 @@ Graphics::Graphics( DG *dg, int argc, char **argv ) throw (class GraphicsExcepti
         
         SDL_ShowCursor( 0 );
 
-        setGrab( _grab );
+        setGrab( g_state.grab_input );
 
         //
         // initialize the GL display lists
@@ -268,7 +267,7 @@ Graphics::~Graphics() {
 }
 
 void Graphics::setGrab( bool flag ) {
-        _grab = flag;
+        g_state.grab_input = flag;
 
         SDL_WM_GrabInput( flag ? SDL_GRAB_ON : SDL_GRAB_OFF );
 
