@@ -8,9 +8,10 @@ GraphicsState::GraphicsState() {
         use_multitex = true;
         has_multitex = false;
         show_cursor = true;
-        show_stats = true;
+        show_stats = false;
         swap_RB = false;
         polygon_smooth_ok = true;
+        grab_input = true;
         total_fps = 0;
         graphics_time = 0;
         graphics_fps = 0;
